@@ -94,13 +94,10 @@ class GANAttention2d(nn.Module):
 
         o = reshape(o, shape=[x.size(0), self.channels,
                               self.height, self.width])
-        y = self.gamma*o + x
-
-        return y
+        return self.gamma*o + x
 
     def init_weights(self):
         for module in self.modules():
             if isinstance(module, nn.Conv2d):
                 nn.init.orthogonal_(module.weight, gain=self.gain)
                 nn.init.constant_(module.bias, 0)
-
